%define anolis_release 2

Name:           libselinux
Version:        3.4
Release:        %{anolis_release}%{?dist}
Summary:        SELinux library and simple utilities 

License:        Public Domain
URL:            https://github.com/SELinuxProject/selinux/wiki
Source0:        https://github.com/SELinuxProject/selinux/releases/download/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  gcc make systemd python3 python3-devel ruby-devel ruby libsepol-static swig pcre2-devel xz-devel 
Requires:       libsepol pcre2

%description
Security-enhanced Linux is a feature of the Linux® kernel and a number
of utilities with enhanced security functionality designed to add
mandatory access controls to Linux.  The Security-enhanced Linux
kernel contains new architectural components originally developed to
improve the security of the Flask operating system. These
architectural components provide general support for the enforcement
of many kinds of mandatory access control policies, including those
based on the concepts of Type Enforcement®, Role-based Access
Control, and Multi-level Security.

libselinux provides an API for SELinux applications to get and set
process and file security contexts and to obtain security policy
decisions.  Required for any applications that use the SELinux API.

%package utils
Summary: SELinux libselinux utilities
Requires: %{name} = %{version}-%{release}

%description utils
The libselinux-utils package contains the utilities

%package -n python3-libselinux
Summary: SELinux python 3 bindings for libselinux
Requires: %{name} = %{version}-%{release}
%{?python_provide:%python_provide python3-libselinux}
Provides: %{name}-python3 = %{version}-%{release}
Obsoletes: %{name}-python3 < %{version}-%{release}

%description -n python3-libselinux
The libselinux-python3 package contains python 3 bindings for developing
SELinux applications.

%package ruby
Summary: SELinux ruby bindings for libselinux
Requires: %{name} = %{version}-%{release}
Provides: ruby(selinux)

%description ruby
The libselinux-ruby package contains the ruby bindings for developing
SELinux applications.

%package devel
Summary: Header files and libraries used to build SELinux
Requires: %{name} = %{version}-%{release}
Requires: libsepol-devel >= 3.3-1 

%description devel
The libselinux-devel package contains the libraries and header files
needed for developing SELinux applications.

%package static
Summary: Static libraries used to build SELinux
Requires: %{name}-devel = %{version}-%{release}

%description static
The libselinux-static package contains the static libraries
needed for developing SELinux applications.


%prep
%autosetup


%build

export DISABLE_RPM="y"
export USE_PCRE2="y"

%set_build_flags
CFLAGS="$CFLAGS -fno-semantic-interposition"

%make_build LIBDIR="%{_libdir}" swigify
%make_build LIBDIR="%{_libdir}" all
%make_build PYTHON=%{__python3} LIBDIR="%{_libdir}" pywrap
%make_build RUBYINC=%(pkg-config --cflags ruby) SHLIBDIR="%{_libdir}" LIBDIR="%{_libdir}" LIBSEPOLA="%{_libdir}/libsepol.a" rubywrap


%install
rm -rf $RPM_BUILD_ROOT
mkdir -p %{buildroot}%{_tmpfilesdir}
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_includedir}
mkdir -p %{buildroot}%{_sbindir}
install -d -m 0755 %{buildroot}%{_rundir}/setrans
echo "d %{_rundir}/setrans 0755 root root" > %{buildroot}%{_tmpfilesdir}/libselinux.conf
make PYTHON=%{__python3} DESTDIR="%{buildroot}" LIBDIR="%{_libdir}" SHLIBDIR="%{_lib}" BINDIR="%{_bindir}" SBINDIR="%{_sbindir}" LIBSEPOLA="%{_libdir}/libsepol.a" install-pywrap
%make_install LIBDIR="%{_libdir}" SHLIBDIR="%{_libdir}"

make DESTDIR="%{buildroot}" RUBYINSTALL=%{ruby_vendorarchdir} install-rubywrap

rm -f %{buildroot}%{_sbindir}/{compute_*,deftype,execcon,getenforcemode,getfilecon,getfilecon,getpidcon,mkdircon,policyvers,setfilecon,selinuxconfig,getseuser,togglesebool,selinux_check_securetty_context}
mv %{buildroot}%{_sbindir}/getdefaultcon %{buildroot}%{_sbindir}/selinuxdefcon
mv %{buildroot}%{_sbindir}/getconlist %{buildroot}%{_sbindir}/selinuxconlist

%generate_compatibility_deps

%ldconfig_scriptlets

%files
%dir %{abidir}
%license LICENSE
%{_libdir}/libselinux.so.*
%{abidir}/libselinux*.dump
%dir %{_rundir}/setrans/
%{_tmpfilesdir}/libselinux.conf

%files utils
%{_sbindir}/*
%{abidir}/*-option.list
%{_mandir}/man5/*
%{_mandir}/man8/*
%{_mandir}/ru/man5/*
%{_mandir}/ru/man8/*

%files devel
%{_libdir}/libselinux.so
%{_libdir}/pkgconfig/libselinux.pc
%{_includedir}/selinux/
%{_mandir}/man3/*

%files static
%{_libdir}/libselinux.a

%files -n python3-libselinux
%{python3_sitearch}/selinux/
%{python3_sitearch}/selinux-%{version}*
%{python3_sitearch}/_selinux*
%{abidir}/selinux.dump
%{abidir}/_selinux*.dump
%{abidir}/audit2why.cpython-310-%{_arch}-linux-gnu.dump


%files ruby
%{ruby_vendorarchdir}/selinux.so

%changelog
* Mon Oct 24 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.4-2
- optimise spec file

* Fri Sep 23 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.4-1
- update to 3.4

* Thu Mar 10 2022 forrest_ly <flin@linux.alibaba.com> - 3.3-1
- Init for Anolis OS 23 
